var indexSectionsWithContent =
{
  0: "abcdefghijklmnopqrstuvwxyz~",
  1: "abcdefghijlmnoprstuvwxz",
  2: "j",
  3: "abcdefghijklmnopqrstuvwxyz~",
  4: "abcdefhiklmnoprstuvwz",
  5: "acemnoprstv",
  6: "acfjkmopstw",
  7: "abcdfghijklmoprstuw",
  8: "alot"
};

var indexSectionNames =
{
  0: "all",
  1: "classes",
  2: "namespaces",
  3: "functions",
  4: "variables",
  5: "typedefs",
  6: "enums",
  7: "enumvalues",
  8: "pages"
};

var indexSectionLabels =
{
  0: "All",
  1: "Classes",
  2: "Namespaces",
  3: "Functions",
  4: "Variables",
  5: "Typedefs",
  6: "Enumerations",
  7: "Enumerator",
  8: "Pages"
};

